identify_code

Function identify_code 

fn identify_code(
    known_contracts: &ContractsByArtifact,
    address_name: Option<&String>,
    code: &[u8],
) -> Option<String>
Identifies code by an exact match against local artifacts. Identities that aren’t local artifacts (e.g. from Etherscan) can’t be checked, so they are kept when nothing matches.