identify_node

Function identify_node 

fn identify_node(
    node: &mut CallTraceNode,
    known_contracts: &ContractsByArtifact,
    identified_contracts: &AddressHashMap<String>,
    sources: &ContractSources,
    identified_code: &mut HashMap<(Address, Bytes), Option<String>>,
) -> Option<String>
Identifies the contract executed by node from its recorded bytecode, since an address can execute different code over time (e.g. after vm.etch), and decodes its internal calls.